band structure 2d plotting Options — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# band structure 2d plotting Options

## surface_cmap

value:

  jet

description:

  Controls the colormap of the surface

## surface_color

value:

  None

description:

  Controls the color of the surface

## surface_spinpol_colors

value:

  []

description:

  Controls the colors of the spin polarized surface

## surface_bands_colors

value:

  []

description:

  Controls the color of the surface per band

## surface_opacity

value:

  1.0

description:

  Controls the opacity of the surface

## surface_clim

value:

  None

description:

  Controls the color scale on the surface

## extended_zone_directions

value:

  None

description:

  Controls how many zone to generate. This is a list of directions to generates. Ex: [[1,0,0],[0,0,1]]

## supercell

value:

  [1, 1, 1]

description:

  Controls how many the supercell size used to generate the fermi surface

## projection_accuracy

value:

  high

description:

  Controls the projection algorithmuse. Either high or normal

## interpolation_factor

value:

  1

description:

  Controls the interpolation factor used on the fermi surface

## brillouin_zone_style

value:

  wireframe

description:

  Controls the wireframe style of the brillouin zone

## brillouin_zone_line_width

value:

  3.5

description:

  Controls the linewidth of the brillouin zone

## brillouin_zone_color

value:

  black

description:

  Controls the color of the wireframe of the brillouin zone

## brillouin_zone_opacity

value:

  1.0

description:

  Controls the opacity of the wireframe of the brillouin zone

## texture_cmap

value:

  jet

description:

  Controls the colormap of the texture

## texture_color

value:

  None

description:

  Controls the color of the texture

## texture_size

value:

  0.1

description:

  Controls the size of the texture

## texture_scale

value:

  False

description:

  Controls the scaling of the texture

## texture_opacity

value:

  1.0

description:

  Controls the opacity of the texture

## add_axes

value:

  True

description:

  Controls if there should be direction axes

## energy_lim

value:

  [-2, 2]

description:

  Controls the limits of the energy axis

## x_axes_label

value:

  Kx

description:

  Controls kx axis label

## y_axes_label

value:

  Ky

description:

  Controls ky axis label

## z_axes_label

value:

  E

description:

  Controls kz axis label

## axes_label_color

value:

  black

description:

  Controls axes label color

## axes_line_width

value:

  6

description:

  Controls the linewdith of th axes label

## add_scalar_bar

value:

  True

description:

  Controls if there is a colorbar

## scalar_bar_title

value:

  None

description:

  Controls scalar bar title font size

## scalar_bar_labels

value:

  6

description:

  Controls the scalar bar labels

## scalar_bar_italic

value:

  False

description:

  Controls the label italic style

## scalar_bar_bold

value:

  False

description:

  Controls the label bold style

## scalar_bar_title_font_size

value:

  None

description:

  Controls scalar bar title font size

## scalar_bar_label_font_size

value:

  None

description:

  Controls scalar bar label font size

## scalar_bar_position_x

value:

  0.4

description:

  Controls scalar bar x position

## scalar_bar_position_y

value:

  0.01

description:

  Controls scalar bar y position

## scalar_bar_color

value:

  black

description:

  Controls scalar bar outline color

## background_color

value:

  white

description:

  Controls the background color

## orbit_gif_n_points

value:

  36

description:

  Controls the number of point on the orbit

## orbit_gif_step

value:

  0.05

description:

  Controls the step size of the orbit

## orbit_mp4_n_points

value:

  36

description:

  Controls the number of point on the orbit

## orbit_mp4_step

value:

  0.05

description:

  Controls the step size of the orbit

## clip_brillouin_zone

value:

  True

description:

  Control clip the brillouin zone

## clip_brillouin_zone_factor

value:

  1.5

description:

  Control how large the clipping is in terms of brillouin zones

## grid

value:

  True

description:

  Control to show a grid

## grid_xtitle

value:

  k$_{x}$ ($AA^{-1}$)

description:

  Controls x axis of the grid

## grid_ytitle

value:

  k$_{y}$ ($AA^{-1}$)

description:

  Controls y axis of the grid

## grid_ztitle

value:

  Energy (eV)

description:

  Controls x axis of the grid

## grid_font_size

value:

  10

description:

  Controls the font size of the grid

## add_fermi_plane

value:

  False

description:

  Adds a plane at the fermi level

## fermi_plane_opacity

value:

  0.25

description:

  Opacity of the fermi plane

## fermi_plane_color

value:

  black

description:

  The fermi plane color

## fermi_plane_size

value:

  0.5

description:

  The fermi plane color

## show_fermi_plane_text

value:

  True

description:

  Shows the Fermi plane text

## fermi_text_position

value:

  [0, 2, 0]

description:

  Position of the fermi text

## plotter_offscreen

value:

  False

description:

  Controls whether the plotter renders offscreen

## plotter_camera_pos

value:

  [1, 1, 1]

description:

  Controls the caemera position of the plotter

## isoslider_title

value:

  Energy iso-value

description:

  Controls title of the isoslider

## isoslider_style

value:

  modern

description:

  Controls isoslider style

## isoslider_color

value:

  black

description:

  Controls isoslider color

## cross_section_slice_linewidth

value:

  5.0

description:

  Controls the linewidth of the slice

## cross_section_slice_show_area

value:

  False

description:

  Controls wheather to show the cross section area